Change IFlow objects' field and method names to clarify the meanings of actions

- Part of ONOS-1687

Change-Id: I2cfda9478c5d2f876d9888b7c70ab64ba2a89890
diff --git a/src/main/java/net/onrc/onos/api/flowmanager/PathFlow.java b/src/main/java/net/onrc/onos/api/flowmanager/PathFlow.java
index 50db020..48053ef 100644
--- a/src/main/java/net/onrc/onos/api/flowmanager/PathFlow.java
+++ b/src/main/java/net/onrc/onos/api/flowmanager/PathFlow.java
@@ -18,7 +18,7 @@
     protected IMatch match;
     protected PortNumber ingressPort;
     protected Path path;
-    protected List<IAction> edgeActions;
+    protected List<IAction> egressActions;
 
     /**
      * Constructor.
@@ -28,15 +28,15 @@
      * @param ingressPort The ingress port number at the ingress node of the
      *        path.
      * @param path Path between ingress and egress edge node.
      * @param edgeActions The list of IAction objects at the egress edge node.
      */
     public PathFlow(String id,
-            IMatch match, PortNumber ingressPort, Path path, List<IAction> edgeActions) {
+            IMatch match, PortNumber ingressPort, Path path, List<IAction> egressActions) {
         this.id = new FlowId(id);
         this.match = match;
         this.ingressPort = ingressPort;
         this.path = path;
-        this.edgeActions = edgeActions;
+        this.egressActions = egressActions;
     }
 
     @Override
@@ -78,7 +78,7 @@
      *
      * @return The list of IAction objects at the egress edge node.
      */
-    public List<IAction> getActions() {
-        return edgeActions;
+    public List<IAction> getEgressActions() {
+        return egressActions;
     }
 }
@@ -28,15 +28,15 @@
      *        path.
      * @param path Path between ingress and egress edge node.
-     * @param edgeActions The list of IAction objects at the egress edge node.
+     * @param egressActions The list of IAction objects at the egress edge node.
      */
     public PathFlow(String id,